PythonModule

Struct PythonModule 

pub struct PythonModule { /* private fields */ }

Implementations

Source

impl PythonModule

pub fn action<T: Send + 'static>( &self, call: fn(&Python<'_>, &Bound<'_, PyAny>) -> PyResult<T>, ) -> PyResult<T>

Runs action on the imported module

 module
    .action(|py, module| module.call_method1("add", (1, 2))?.extract::<i64>())
    .unwrap();
pub fn new_module(path: &Path) -> PyResult<PythonModule>

Loads a Python module from a directory let module = PythonModule::new_module(Path::new("./my-module")).unwrap();

pub fn new_project(init_file: PathBuf) -> PyResult<PythonModule>

Loads a Python project from root file let project = PythonModule::new_project(Path::new("./my-project/main.py").into()).unwrap()